'use strict'
const path = require('path')
const defaultSettings = require('./src/index/settings.js')
// 配置接口环境地址
const baseUrl = 'https://easy-mock.com/mock/5ce73ac90edc0c38e2a1ad97'
const uploadUrl = 'http://192.168.100.215:9999'

function resolve(dir) {
  return path.join(__dirname, dir)
}

const name = defaultSettings.title || 'vue Admin Template' // page title
// If your port is set to 80,
// use administrator privileges to execute the command line.
// For example, Mac: sudo npm run
const port = 9900 // dev port

// All configuration item explanations can be find in https://cli.vuejs.org/config/
module.exports = {
  /**
   * You will need to set publicPath if you plan to deploy your site under a sub path,
   * for example GitHub Pages. If you plan to deploy your site to https://foo.github.io/bar/,
   * then publicPath should be set to "/bar/".
   * In most cases please use '/' !!!
   * Detail: https://cli.vuejs.org/config/#publicpath
   */
  publicPath: process.env.NODE_ENV === 'development' ? '/' : '/',
  outputDir: 'dist',
  assetsDir: 'static',
  lintOnSave: process.env.NODE_ENV === 'development',
  productionSourceMap: false,
  // pages: {
  //   index: {
  //     // page 的入口
  //     entry: './src/index/main.js'
  //     // 模板来源
  //     // template: 'public/index.html',
  //     // // 在 dist/index.html 的输出
  //     // filename: 'index.html',
  //     // // 当使用 title 选项时，
  //     // // template 中的 title 标签需要是 <title><%= htmlWebpackPlugin.options.title %></title>
  //     // title: 'Index Page',
  //     // // 在这个页面中包含的块，默认情况下会包含
  //     // // 提取出来的通用 chunk 和 vendor chunk。
  //     // chunks: ['chunk-vendors', 'chunk-common', 'index']
  //   }
  //   // 当使用只有入口的字符串格式时，
  //   // 模板会被推导为 `public/subpage.html`
  //   // 并且如果找不到的话，就回退到 `public/index.html`。
  //   // 输出文件名会被推导为 `subpage.html`。
  //   // subpage: 'src/subpage/main.js'
  // },
  devServer: {
    port: port,
    open: true,
    overlay: {
      warnings: false,
      errors: true
    },
    // proxy: {
    //   // change xxx-api/login => mock/login
    //   // detail: https://cli.vuejs.org/config/#devserver-proxy
    //   [process.env.VUE_APP_BASE_API]: {
    //     target: `http://localhost:${port}/mock`,
    //     changeOrigin: true,
    //     pathRewrite: {
    //       ['^' + process.env.VUE_APP_BASE_API]: ''
    //     }
    //   }
    // },
    proxy: {
      '/auth': {
        target: baseUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/auth': '/auth'
        }
      },
      '/fs': {
        target: uploadUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/fs': '/fs'
        }
      },
      '/admin': {
        target: baseUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/admin': '/admin'
        }
      },
      '/crm': {
        target: baseUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/crm': '/crm'
        }
      },
      '/distrition': {
        target: baseUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/distrition': '/distrition'
        }
      },
      '/projectdb': {
        target: baseUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/projectdb': '/projectdb'
        }
      },
      '/cd': {
        target: baseUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/cd': '/cd'
        }
      },
      '/ub': {
        target: baseUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/ub': '/ub'
        }
      },
      '/mgr': {
        target: baseUrl,
        changeOrigin: true,
        ws: false,
        secure: false,
        pathRewrite: {
          '^/mgr': '/mgr'
        }
      }
    }
    // after: require('./mock/mock-server.js')
  },
  configureWebpack: {
    // provide the app's title in webpack's name field, so that
    // it can be accessed in index.html to inject the correct title.
    name: name,
    resolve: {
      alias: {
        '@': resolve('src'),
        'packages': resolve('packages')
      }
    }
  },
  chainWebpack(config) {
    /*config
      .module
      .rule('js')
      .include
      .add('/packages')
      .end()
      .use('babel')
      .loader('babel-loader')
      .tap(options => {
        // 修改它的选项...
        return options
      })*/
    config.plugins.delete('preload') // TODO: need test
    config.plugins.delete('prefetch') // TODO: need test

    // set svg-sprite-loader
    config.module
      .rule('svg')
      .exclude.add(resolve('src/icons'))
      .end()
    config.module
      .rule('icons')
      .test(/\.svg$/)
      .include.add(resolve('src/icons'))
      .end()
      .use('svg-sprite-loader')
      .loader('svg-sprite-loader')
      .options({
        symbolId: 'icon-[name]'
      })
      .end()

    // set preserveWhitespace
    config.module
      .rule('vue')
      .use('vue-loader')
      .loader('vue-loader')
      .tap(options => {
        options.compilerOptions.preserveWhitespace = true
        return options
      })
      .end()

    config
      // https://webpack.js.org/configuration/devtool/#development
      .when(process.env.NODE_ENV === 'development',
        config => config.devtool('cheap-source-map')
      )

    config
      .when(process.env.NODE_ENV !== 'development',
        config => {
          /*config
            .plugin('ScriptExtHtmlWebpackPlugin')
            .after('html')
            .use('script-ext-html-webpack-plugin', [{
              // `runtime` must same as runtimeChunk name. default is `runtime`
              inline: /runtime\..*\.js$/
            }])
            .end()*/
          config
            .optimization.splitChunks({
              chunks: 'all',
              cacheGroups: {
                libs: {
                  name: 'chunk-libs',
                  test: /[\\/]node_modules[\\/]/,
                  priority: 10,
                  chunks: 'initial' // only package third parties that are initially dependent
                },
                elementUI: {
                  name: 'chunk-elementUI', // split elementUI into a single package
                  priority: 20, // the weight needs to be larger than libs and app or it will be packaged into libs or app
                  test: /[\\/]node_modules[\\/]_?element-ui(.*)/ // in order to adapt to cnpm
                },
                commons: {
                  name: 'chunk-commons',
                  test: resolve('src/components'), // can customize your rules
                  minChunks: 3, //  minimum common number
                  priority: 5,
                  reuseExistingChunk: true
                }
              }
            })
          config.optimization.runtimeChunk('single')
        }
      )
  }
}
